@@ -15,11 +15,11 @@
 """Interpreting stat() results."""
 
 # pylint: disable=g-multiple-import
-from __go__.os import ModeDir, ModePerm
+from '__go__/os' import ModeDir, ModePerm
 
 
 def S_ISDIR(mode):  # pylint: disable=invalid-name
-  return mode & ModeDir
+  return mode & ModeDir != 0
 
 
 def S_IMODE(mode):  # pylint: disable=invalid-name
