@@ -20,10 +20,10 @@ import UserDict
 # import time
 # import struct
 # import sysconfig
-# try:
-#     import thread
-# except ImportError:
-#     thread = None
+try:
+    import thread
+except ImportError:
+    thread = None
 
 __all__ = [
     "Error", "TestFailed", "have_unicode", "BasicTestRunner", "run_unittest",
@@ -188,67 +188,67 @@ verbose = 1              # Flag set to 0 by regrtest.py
 #     except KeyError:
 #         pass
 
-# if sys.platform.startswith("win"):
-#     def _waitfor(func, pathname, waitall=False):
-#         # Perform the operation
-#         func(pathname)
-#         # Now setup the wait loop
-#         if waitall:
-#             dirname = pathname
-#         else:
-#             dirname, name = os.path.split(pathname)
-#             dirname = dirname or '.'
-#         # Check for `pathname` to be removed from the filesystem.
-#         # The exponential backoff of the timeout amounts to a total
-#         # of ~1 second after which the deletion is probably an error
-#         # anyway.
-#         # Testing on a i7@4.3GHz shows that usually only 1 iteration is
-#         # required when contention occurs.
-#         timeout = 0.001
-#         while timeout < 1.0:
-#             # Note we are only testing for the existence of the file(s) in
-#             # the contents of the directory regardless of any security or
-#             # access rights.  If we have made it this far, we have sufficient
-#             # permissions to do that much using Python's equivalent of the
-#             # Windows API FindFirstFile.
-#             # Other Windows APIs can fail or give incorrect results when
-#             # dealing with files that are pending deletion.
-#             L = os.listdir(dirname)
-#             if not (L if waitall else name in L):
-#                 return
-#             # Increase the timeout and try again
-#             time.sleep(timeout)
-#             timeout *= 2
-#         warnings.warn('tests may fail, delete still pending for ' + pathname,
-#                       RuntimeWarning, stacklevel=4)
+if sys.platform.startswith("win"):
+    def _waitfor(func, pathname, waitall=False):
+        # Perform the operation
+        func(pathname)
+        # Now setup the wait loop
+        if waitall:
+            dirname = pathname
+        else:
+            dirname, name = os.path.split(pathname)
+            dirname = dirname or '.'
+        # Check for `pathname` to be removed from the filesystem.
+        # The exponential backoff of the timeout amounts to a total
+        # of ~1 second after which the deletion is probably an error
+        # anyway.
+        # Testing on a i7@4.3GHz shows that usually only 1 iteration is
+        # required when contention occurs.
+        timeout = 0.001
+        while timeout < 1.0:
+            # Note we are only testing for the existence of the file(s) in
+            # the contents of the directory regardless of any security or
+            # access rights.  If we have made it this far, we have sufficient
+            # permissions to do that much using Python's equivalent of the
+            # Windows API FindFirstFile.
+            # Other Windows APIs can fail or give incorrect results when
+            # dealing with files that are pending deletion.
+            L = os.listdir(dirname)
+            if not (L if waitall else name in L):
+                return
+            # Increase the timeout and try again
+            time.sleep(timeout)
+            timeout *= 2
+        warnings.warn('tests may fail, delete still pending for ' + pathname,
+                      RuntimeWarning, stacklevel=4)
 
-#     def _unlink(filename):
-#         _waitfor(os.unlink, filename)
+    def _unlink(filename):
+        _waitfor(os.unlink, filename)
 
-#     def _rmdir(dirname):
-#         _waitfor(os.rmdir, dirname)
+    def _rmdir(dirname):
+        _waitfor(os.rmdir, dirname)
 
-#     def _rmtree(path):
-#         def _rmtree_inner(path):
-#             for name in os.listdir(path):
-#                 fullname = os.path.join(path, name)
-#                 if os.path.isdir(fullname):
-#                     _waitfor(_rmtree_inner, fullname, waitall=True)
-#                     os.rmdir(fullname)
-#                 else:
-#                     os.unlink(fullname)
-#         _waitfor(_rmtree_inner, path, waitall=True)
-#         _waitfor(os.rmdir, path)
-# else:
-#     _unlink = os.unlink
-#     _rmdir = os.rmdir
-#     _rmtree = shutil.rmtree
+    def _rmtree(path):
+        def _rmtree_inner(path):
+            for name in os.listdir(path):
+                fullname = os.path.join(path, name)
+                if os.path.isdir(fullname):
+                    _waitfor(_rmtree_inner, fullname, waitall=True)
+                    os.rmdir(fullname)
+                else:
+                    os.unlink(fullname)
+        _waitfor(_rmtree_inner, path, waitall=True)
+        _waitfor(os.rmdir, path)
+else:
+    _unlink = os.unlink
+    _rmdir = os.rmdir
+#    _rmtree = shutil.rmtree
 
-# def unlink(filename):
-#     try:
-#         _unlink(filename)
-#     except OSError:
-#         pass
+def unlink(filename):
+    try:
+        _unlink(filename)
+    except OSError:
+        pass
 
 # def rmdir(dirname):
 #     try:
@@ -569,14 +569,14 @@ try:
 except NameError:
     have_unicode = False
 
-# requires_unicode = unittest.skipUnless(have_unicode, 'no unicode support')
+requires_unicode = unittest.skipUnless(have_unicode, 'no unicode support')
 
 # def u(s):
 #     return unicode(s, 'unicode-escape')
 
-# # FS_NONASCII: non-ASCII Unicode character encodable by
-# # sys.getfilesystemencoding(), or None if there is no such character.
-# FS_NONASCII = None
+# FS_NONASCII: non-ASCII Unicode character encodable by
+# sys.getfilesystemencoding(), or None if there is no such character.
+FS_NONASCII = None
 # if have_unicode:
 #     for character in (
 #         # First try printable and common characters to have a readable filename.
@@ -620,14 +620,14 @@ except NameError:
 #             FS_NONASCII = character
 #             break
 
-# # Filename used for testing
-# if os.name == 'java':
-#     # Jython disallows @ in module names
-#     TESTFN = '$test'
-# elif os.name == 'riscos':
-#     TESTFN = 'testfile'
-# else:
-#     TESTFN = '@test'
+# Filename used for testing
+if os.name == 'java':
+    # Jython disallows @ in module names
+    TESTFN = '$test'
+elif os.name == 'riscos':
+    TESTFN = 'testfile'
+else:
+    TESTFN = '@test'
 #     # Unicode name only used if TEST_FN_ENCODING exists for the platform.
 #     if have_unicode:
 #         # Assuming sys.getfilesystemencoding()!=sys.getdefaultencoding()
@@ -666,10 +666,9 @@ except NameError:
 #                 'Unicode filename tests may not be effective' \
 #                 % TESTFN_UNENCODABLE
 
-
-# # Disambiguate TESTFN for parallel testing, while letting it remain a valid
-# # module name.
-# TESTFN = "{}_{}_tmp".format(TESTFN, os.getpid())
+# Disambiguate TESTFN for parallel testing, while letting it remain a valid
+# module name.
+TESTFN = "%s_%s_tmp" % (TESTFN, os.getpid())
 
 # # Save the initial cwd
 # SAVEDCWD = os.getcwd()
@@ -1512,34 +1511,34 @@ def run_unittest(*classes):
 #         print 'doctest (%s) ... %d tests with zero failures' % (module.__name__, t)
 #     return f, t
 
-# #=======================================================================
-# # Threading support to prevent reporting refleaks when running regrtest.py -R
+#=======================================================================
+# Threading support to prevent reporting refleaks when running regrtest.py -R
 
-# # NOTE: we use thread._count() rather than threading.enumerate() (or the
-# # moral equivalent thereof) because a threading.Thread object is still alive
-# # until its __bootstrap() method has returned, even after it has been
-# # unregistered from the threading module.
-# # thread._count(), on the other hand, only gets decremented *after* the
-# # __bootstrap() method has returned, which gives us reliable reference counts
-# # at the end of a test run.
+# NOTE: we use thread._count() rather than threading.enumerate() (or the
+# moral equivalent thereof) because a threading.Thread object is still alive
+# until its __bootstrap() method has returned, even after it has been
+# unregistered from the threading module.
+# thread._count(), on the other hand, only gets decremented *after* the
+# __bootstrap() method has returned, which gives us reliable reference counts
+# at the end of a test run.
 
-# def threading_setup():
-#     if thread:
-#         return thread._count(),
-#     else:
-#         return 1,
+def threading_setup():
+    if thread:
+        return (thread._count(),)
+    else:
+        return (1,)
 
-# def threading_cleanup(nb_threads):
-#     if not thread:
-#         return
+def threading_cleanup(nb_threads):
+    if not thread:
+        return
 
-#     _MAX_COUNT = 10
-#     for count in range(_MAX_COUNT):
-#         n = thread._count()
-#         if n == nb_threads:
-#             break
-#         time.sleep(0.1)
-#     # XXX print a warning in case of failure?
+    _MAX_COUNT = 10
+    for count in range(_MAX_COUNT):
+        n = thread._count()
+        if n == nb_threads:
+            break
+        time.sleep(0.1)
+    # XXX print a warning in case of failure?
 
 # def reap_threads(func):
 #     """Use this function when threads are being used.  This will
@@ -1558,25 +1557,25 @@ def run_unittest(*classes):
 #             threading_cleanup(*key)
 #     return decorator
 
-# def reap_children():
-#     """Use this function at the end of test_main() whenever sub-processes
-#     are started.  This will help ensure that no extra children (zombies)
-#     stick around to hog resources and create problems when looking
-#     for refleaks.
-#     """
+def reap_children():
+    """Use this function at the end of test_main() whenever sub-processes
+    are started.  This will help ensure that no extra children (zombies)
+    stick around to hog resources and create problems when looking
+    for refleaks.
+    """
 
-#     # Reap all our dead child processes so we don't leave zombies around.
-#     # These hog resources and might be causing some of the buildbots to die.
-#     if hasattr(os, 'waitpid'):
-#         any_process = -1
-#         while True:
-#             try:
-#                 # This will raise an exception on Windows.  That's ok.
-#                 pid, status = os.waitpid(any_process, os.WNOHANG)
-#                 if pid == 0:
-#                     break
-#             except:
-#                 break
+    # Reap all our dead child processes so we don't leave zombies around.
+    # These hog resources and might be causing some of the buildbots to die.
+    if hasattr(os, 'waitpid'):
+        any_process = -1
+        while True:
+            try:
+                # This will raise an exception on Windows.  That's ok.
+                pid, status = os.waitpid(any_process, os.WNOHANG)
+                if pid == 0:
+                    break
+            except:
+                break
 
 # @contextlib.contextmanager
 # def start_threads(threads, unlock=None):
