@@ -104,6 +104,7 @@ var builtinTypes = map[*Type]*builtinTypeInfo{
 	BaseExceptionType:             {init: initBaseExceptionType, global: true},
 	BaseStringType:                {init: initBaseStringType, global: true},
 	BoolType:                      {init: initBoolType, global: true},
+	ByteArrayType:                 {init: initByteArrayType, global: true},
 	BytesWarningType:              {global: true},
 	CodeType:                      {},
 	ComplexType:                   {init: initComplexType, global: true},
@@ -130,6 +131,7 @@ var builtinTypes = map[*Type]*builtinTypeInfo{
 	IndexErrorType:                {global: true},
 	IntType:                       {init: initIntType, global: true},
 	IOErrorType:                   {global: true},
+	KeyboardInterruptType:         {global: true},
 	KeyErrorType:                  {global: true},
 	listIteratorType:              {init: initListIteratorType},
 	ListType:                      {init: initListType, global: true},
@@ -340,20 +342,26 @@ func builtinDir(f *Frame, args Args, kwargs KWArgs) (*Object, *BaseException) {
 	}
 	d := NewDict()
 	o := args[0]
-	if o.dict != nil {
-		raised := seqForEach(f, o.dict.ToObject(), func(k *Object) *BaseException {
-			return d.SetItem(f, k, None)
-		})
-		if raised != nil {
-			return nil, raised
+	switch {
+	case o.isInstance(TypeType):
+		for _, t := range toTypeUnsafe(o).mro {
+			if raised := d.Update(f, t.Dict().ToObject()); raised != nil {
+				return nil, raised
+			}
 		}
-	}
-	for _, t := range o.typ.mro {
-		raised := seqForEach(f, t.dict.ToObject(), func(k *Object) *BaseException {
-			return d.SetItem(f, k, None)
-		})
-		if raised != nil {
-			return nil, raised
+	case o.isInstance(ModuleType):
+		d.Update(f, o.Dict().ToObject())
+	default:
+		d = NewDict()
+		if dict := o.Dict(); dict != nil {
+			if raised := d.Update(f, dict.ToObject()); raised != nil {
+				return nil, raised
+			}
+		}
+		for _, t := range o.typ.mro {
+			if raised := d.Update(f, t.Dict().ToObject()); raised != nil {
+				return nil, raised
+			}
 		}
 	}
 	l := d.Keys(f)
@@ -746,6 +754,7 @@ Outer:
 
 func init() {
 	builtinMap := map[string]*Object{
+		"__debug__":      False.ToObject(),
 		"__frame__":      newBuiltinFunction("__frame__", builtinFrame).ToObject(),
 		"abs":            newBuiltinFunction("abs", builtinAbs).ToObject(),
 		"all":            newBuiltinFunction("all", builtinAll).ToObject(),
